==> haskell-recv-0.1.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.0
visibility:           public
id:                   recv-0.1.0-7vP8XtyPxnN9p6uab5UwTv
key:                  recv-0.1.0-7vP8XtyPxnN9p6uab5UwTv
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  a218193b2a8fdd328151a51a69cf5305
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types Network.Socket.BufferPool.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.0-7vP8XtyPxnN9p6uab5UwTv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-24l6wfZeDaoIo68scGYLPE

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recv-0.1.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.0
visibility:           public
id:                   recv-0.1.0-BRP6iqMZoBXF8f4qys212l
key:                  recv-0.1.0-BRP6iqMZoBXF8f4qys212l
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  be9297a3bb51fffa446fa435273cf0f8
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types Network.Socket.BufferPool.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.0-BRP6iqMZoBXF8f4qys212l
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-IeirKeGjruDCEk80u2jHD1

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
